summaryrefslogtreecommitdiffstats
path: root/certmanager/certificateinfowidgetimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/certificateinfowidgetimpl.cpp')
-rw-r--r--certmanager/certificateinfowidgetimpl.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/certmanager/certificateinfowidgetimpl.cpp b/certmanager/certificateinfowidgetimpl.cpp
index 4932b6bd..8ce43aa5 100644
--- a/certmanager/certificateinfowidgetimpl.cpp
+++ b/certmanager/certificateinfowidgetimpl.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -54,7 +54,7 @@
#include <kprocio.h>
#include <kglobalsettings.h>
-// Qt
+// TQt
#include <tqlistview.h>
#include <tqtextedit.h>
#include <tqheader.h>
@@ -69,8 +69,8 @@
#include <assert.h>
CertificateInfoWidgetImpl::CertificateInfoWidgetImpl( const GpgME::Key & key, bool external,
- TQWidget * parent, const char * name )
- : CertificateInfoWidget( parent, name ),
+ TQWidget * tqparent, const char * name )
+ : CertificateInfoWidget( tqparent, name ),
mExternal( external ),
mFoundIssuer( true ),
mHaveKeyLocally( false )
@@ -182,14 +182,14 @@ void CertificateInfoWidgetImpl::setKey( const GpgME::Key & key ) {
startCertificateDump();
}
-static void showChainListError( TQWidget * parent, const GpgME::Error & err, const char * subject ) {
+static void showChainListError( TQWidget * tqparent, const GpgME::Error & err, const char * subject ) {
assert( err );
const TQString msg = i18n("<qt><p>An error occurred while fetching "
"the certificate <b>%1</b> from the backend:</p>"
"<p><b>%2</b></p></qt>")
- .arg( subject ? TQString::fromUtf8( subject ) : TQString::null,
+ .arg( subject ? TQString::fromUtf8( subject ) : TQString(),
TQString::fromLocal8Bit( err.asString() ) );
- KMessageBox::error( parent, msg, i18n("Certificate Listing Failed" ) );
+ KMessageBox::error( tqparent, msg, i18n("Certificate Listing Failed" ) );
}
void CertificateInfoWidgetImpl::startCertificateChainListing() {
@@ -329,7 +329,7 @@ void CertificateInfoWidgetImpl::updateChainView() {
else {
item = new TQListViewItem( pathView, i18n("Issuer certificate not found ( %1)")
.arg( Kleo::DN( (*it).issuerName() ).prettyDN() ) );
- item->setOpen( true ); // Qt bug: doesn't open after setEnabled( false ) :/
+ item->setOpen( true ); // TQt bug: doesn't open after setEnabled( false ) :/
item->setEnabled( false );
}
item->setOpen( true );
@@ -358,7 +358,7 @@ void CertificateInfoWidgetImpl::slotShowCertPathDetails( TQListViewItem * item )
// find the key corresponding to "item". This hack would not be
// necessary if pathView was a Kleo::KeyListView, but it's
- // Qt-Designer-generated and I don't feel like creating a custom
+ // TQt-Designer-generated and I don't feel like creating a custom
// widget spec for Kleo::KeyListView.
unsigned int totalCount = 0;
int itemIndex = -1;